@@ -343,72 +343,11 @@ def write_plink_files(
     map_df: pd.DataFrame,
     outdir: str,
     split_index: int = 6,
-) -> None:
-    """
-    Write PED / MAP / PHENO files for a given measurement number.  PED file
-    writing is different for DO animals.
-
-    All dependencies (pheno_ped, map_df, outdir) are explicit parameters.
-    """
-    df = pheno_ped[pheno_ped["measnum"] == measnum]
-    if df.empty:
-        return
-
-    def _do_sex(sex_flag: str) -> None:
-        if sex_flag not in df["sex"].unique():
-            return
-        df_s = df[df["sex"] == sex_flag]
-
-        # PHENO
-        fast_write_space(
-            df_s[["FID", "IID", "zscore", "value"]],
-            os.path.join(outdir, f"{measnum}.{sex_flag}.pheno"),
-        )
-
-        # PED
-        int_cols = [c for c in df_s.columns if isinstance(c, int)]
-        allele_block = df_s[int_cols]
-
-        # Heuristic: if we see a space in any genotype cell, it's a "pair" (e.g., "1 2") -> needs splitting
-        # Limit check to a small sample for speed
-        sample_vals = allele_block.to_numpy(dtype=object)
-        sample_vals = sample_vals.ravel()[:1000] if sample_vals.size > 1000 else sample_vals.ravel()
-        needs_split = any((" " in str(v)) for v in sample_vals)
-
-        if needs_split:
-            allele_df = column_splitter_vec(allele_block, split_index=split_index)
-        else:
-            # Already one-allele-per-column (DO): just pass through
-            allele_df = allele_block
-
-        fast_write_space(
-            allele_df,
-            os.path.join(outdir, f"{measnum}.{sex_flag}.ped"),
-        )
-
-        # MAP
-        fast_write_tsv(
-            map_df,
-            os.path.join(outdir, f"{measnum}.{sex_flag}.map"),
-        )
-
-    _do_sex("f")
-    _do_sex("m")
-
-
-def write_plink_files_VA(
-    measnum: int,
-    pheno_ped: pd.DataFrame,
-    map_df: pd.DataFrame,
-    outdir: str,
-    split_index: int = 6,
 ) -> None:
     """
     Write PED / MAP / PHENO files for a given measurement number.
 
     All dependencies (pheno_ped, map_df, outdir) are explicit parameters.
-
-    (A: works for NON-Do as of 10/17)
     """
     df = pheno_ped[pheno_ped["measnum"] == measnum]
     if df.empty:
@@ -452,128 +391,6 @@ def generate_pheno_plink(
 ) -> pd.DataFrame:
     """
     Generates PLINK-formatted .ped, .map, and .pheno files for phenotype data, stratified by sex and measurement number.
-    [NEW] Updated to handle DO panel type.
-
-    Args:
-        ped_file: Path to the input PED file.
-        map_file: Path to the input MAP file.
-        pheno: DataFrame containing phenotype data with columns ['strain', 'sex', 'measnum', 'zscore', 'value'].
-        outdir: Directory where output files will be saved.
-        ncore: Number of cores to use for parallel processing.
-
-    Returns:
-        pheno_s: Processed phenotype data filtered and sorted by strain.
-    """
-    # Ensure the output directory exists
-    if not os.path.exists(outdir):
-        os.makedirs(outdir)
-
-    # Normalize strain names in phenotype data
-    pheno['strain'] = pheno['strain'].str.replace(" ", "").str.upper()
-
-    # Read map file
-    map_df = pd.read_csv(map_file, header=None, sep="\t")
-    map_df[1] = np.where(map_df[1] == ".", map_df[0].astype(str) + "_" + map_df[3].astype(str), map_df[1].astype(str))
-    logging.debug(
-        "[generate_pheno_plink] MAP read %s, df shape: %s.",
-        map_file,
-        map_df.shape
-    )
-    logging.debug("[generate_pheno_plink] map file read and santized")
-    
-    # Read ped file
-    ped_df = read_pyarrow(ped_file)
-    ped_df.columns = range(ped_df.shape[1])
-
-    meta_cols = [0, 1, 2, 3, 4, 5]
-    ped_df[meta_cols] = ped_df[meta_cols].astype(str)
-
-    ped_df[0] = ped_df[0].str.replace("?", "").str.replace(" ", "").str.upper()
-    ped_df[1] = ped_df[1].str.replace("?", "").str.replace(" ", "").str.upper()
-    logging.debug("[generate_pheno_plink] ped file read and santized")
-
-    # After reading/sanitizing ped_df[0]/[1] to strings:
-    ped_ids = set(ped_df[0].astype(str))
-
-    # Normalize pheno fields we'll try as keys
-    pheno["strain_norm"]    = pheno["strain"].astype(str).str.replace(" ", "").str.upper()
-    pheno["animal_id_norm"] = pheno["animal_id"].astype(str).str.replace(" ", "").str.upper()
-
-    # Pick the key that actually intersects PED FID
-    overlap_strain = len(set(pheno["strain_norm"])    & ped_ids)
-    overlap_animal = len(set(pheno["animal_id_norm"]) & ped_ids)
-
-    if overlap_strain > 0:
-        logging.debug("[generate_pheno_plink] strain is being used as join key - NON-DO")
-        join_key = "strain_norm"     # NON-DO behavior
-    elif overlap_animal > 0:
-        logging.debug("[generate_pheno_plink] animal_id is being used as join key - DO")
-        join_key = "animal_id_norm"  # DO behavior
-    else:
-        raise ValueError(
-            f"No ID overlap with PED: tried STRAIN({overlap_strain}) and ANIMAL_ID({overlap_animal}). "
-            "Make sure PED col0 matches either strain or animal_id."
-        )
-
-    # Filter/sort pheno using the chosen key
-    pheno_s = pheno[(pheno["sex"].isin(["f", "m"])) & (pheno[join_key].isin(ped_df[0]))]
-    pheno_s = pheno_s.sort_values(by=join_key)
-
-    # Count per key
-    pheno_n = (pheno_s[join_key].value_counts()
-               .rename_axis(join_key)
-               .reset_index(name="count")
-               .sort_values(by=join_key))
-
-    # Subset/sort PED on FID (col 0) with same order as pheno_n
-    ped_s = (ped_df[ped_df[0].isin(pheno_s[join_key])]
-                .sort_values(by=0)
-                .reset_index(drop=True))
-
-    # Sanity: PED FIDs must align with pheno_n keys in the same order
-    assert pheno_n[join_key].tolist() == ped_s[0].tolist(), \
-        "ID mismatch between phenotype and PED after sorting."
-
-    # Expand PED rows to match per-row phenotype
-    pheno_ped_n = ped_s.loc[ped_s.index.repeat(pheno_n["count"].values)].reset_index(drop=True)
-
-    # Combine; keep existing sex/zscore wiring
-    pheno_ped = pd.concat([pheno_s.reset_index(drop=True), pheno_ped_n.reset_index(drop=True)], axis=1)
-    pheno_ped[4] = np.where(pheno_ped["sex"] == "f", 2, 1)  # SEX
-    pheno_ped[5] = pheno_ped["zscore"]                     # PHE
-
-    # Ensure FID/IID columns present and consistent with PED
-    pheno_ped["FID"] = pheno_ped[0]
-    pheno_ped["IID"] = pheno_ped[1]
-
-    logging.debug("[generate_pheno_plink] Combined phenotype data with PED data and set necessary columns.")
-
-    # Write files for each measure
-    Parallel(n_jobs=ncore)(
-        delayed(write_plink_files)(
-            measnum,
-            pheno_ped=pheno_ped,
-            map_df=map_df,
-            outdir=outdir,
-            split_index=6
-        )
-        for measnum in pheno_ped["measnum"].unique()
-    )
-
-    return pheno_s
-
-
-def generate_pheno_plink_VA(
-    ped_file: str,
-    map_file: str,
-    pheno: pd.DataFrame,
-    outdir: str,
-    ncore: int
-) -> pd.DataFrame:
-    """
-    Generates PLINK-formatted .ped, .map, and .pheno files for phenotype data, stratified by sex and measurement number.
-
-    (A: works for NON-Do as of 10/17), need a new version to handle DO panel.
 
     Args:
         ped_file: Path to the input PED file.
